@@ -4,7 +4,19 @@ from .base import TextWidget
 
 class Slider(TextWidget):
 
-    def __init__(self, master, start=0, end=100, horizontal=True, command=None, grid=None, align=None, visible=True, enabled=None, width=None, height=None):
+    def __init__(
+        self, 
+        master, 
+        start=0, 
+        end=100, 
+        horizontal=True, 
+        command=None, 
+        grid=None, 
+        align=None, 
+        visible=True, 
+        enabled=None, 
+        width=None, 
+        height=None):
 
         description = "[Slider] object from " + str(start) + " to " + str(end)
 
@@ -71,10 +83,3 @@ class Slider(TextWidget):
             self._command = lambda: None
         else:
             self._command = command
-
-    # DEPRECATED
-    # -------------------------------------------
-
-    def add_command(self, command):
-        self.update_command(command)
-        utils.deprecated("Slider add_command() is deprecated - renamed to update_command()")
