@@ -8,10 +8,10 @@ class Text(TextWidget):
         self,
         master,
         text="",
-        size=12,
-        color="black",
+        size=None,
+        color=None,
         bg=None,
-        font="Helvetica",
+        font=None,
         grid=None,
         align=None,
         visible=True,
@@ -22,12 +22,21 @@ class Text(TextWidget):
         description = "[Text] object with text \"" + str(text) + "\""
 
         self._text = str(text)
-        tk = Label(master.tk, text=text, fg=utils.convert_color(color), bg=utils.convert_color(bg), font=(font, size))
-
+        tk = Label(master.tk, text=text)
         super(Text, self).__init__(master, tk, description, grid, align, visible, enabled, width, height)
 
+        # setup defaults
         if bg:
             self.bg = bg
+        
+        if size is not None:
+            self.text_size = size
+
+        if font is not None:
+            self.font = font
+
+        if color is not None:
+            self.text_color = color
 
     # PROPERTIES
     # ----------------------------------
@@ -67,33 +76,3 @@ class Text(TextWidget):
         self.tk.config(text=new_text)
         self.description = "[Text] object with text \"" + new_text + "\""
 
-
-    # DEPRECATED METHODS
-    # --------------------------------------------
-
-    # Sets the text colour
-    def color(self, color):
-        self.text_color = color
-        utils.deprecated("Text color() is deprecated. Please use the text_color property instead.")
-
-    # Set the font
-    def font_face(self, font):
-        self.font = font
-        utils.deprecated("Text font_face() is deprecated. Please use font property instead.")
-
-    # Set the font size
-    def font_size(self, size):
-        self.size = size
-        utils.deprecated("Text font_size() is deprecated. Please use the size property instead.")
-
-     # Returns the text
-    def get(self):
-        return self._text
-        utils.deprecated("Text get() is deprecated. Please use the value property instead.")
-
-    # Sets the text
-    def set(self, text):
-        self._text = str(text)
-        self.tk.config(text=self._text)
-        self.description = "[Text] object with text \"" + str(text) + "\""
-        utils.deprecated("Text set() is deprecated. Please use the value property instead.")
