@@ -5,7 +5,21 @@ from .event import EventManager
 
 class Waffle(Widget):
 
-    def __init__(self, master, height=3, width=3, dim=20, pad=5, color="white", dotty=False, grid=None, align=None, command=None, remember=True, visible=True, enabled=None, bg=None):
+    def __init__(
+        self, 
+        master, 
+        height=3, 
+        width=3, 
+        dim=20, 
+        pad=5, 
+        color="white", 
+        dotty=False, 
+        grid=None, 
+        align=None, 
+        command=None,  
+        visible=True, 
+        enabled=None, 
+        bg=None):
 
         description = "[Waffle] object ({}x{})".format(height, width)
 
