@@ -1,3 +1,8 @@
+__name__ = "guizero"
+__package__ = "guizero"
+__version__ = '1.1.0'
+__author__ = "Laura Sach"
+
 from sys import exit
 try:
     from tkinter import Tk
@@ -7,13 +12,14 @@ except ImportError:
 
 from . import utilities as utils
 from .utilities import system_config
-from .alerts import *
+from .dialog import *
 
 from .App import App
 from .Box import Box
 from .ButtonGroup import ButtonGroup
 from .CheckBox import CheckBox
 from .Combo import Combo
+from .Drawing import Drawing
 from .ListBox import ListBox
 from .MenuBar import MenuBar
 from .Picture import Picture
@@ -24,4 +30,4 @@ from .Text import Text
 from .TextBox import TextBox
 from .PushButton import PushButton
 from .Waffle import Waffle
-from .Window import Window
\ No newline at end of file
+from .Window import Window
