@@ -15,9 +15,8 @@ from .tkmixins import (
 
 from . import utilities as utils
 from .event import EventManager
+from . import dialog
 from tkinter import BOTH, X, Y, YES
-from . import utilities as utils
-
 
 class Base():
 
@@ -286,6 +285,40 @@ class Container(Component):
         """
         return self._children
 
+    def add_tk_widget(self, tk_widget, grid=None, align=None, visible=True, enabled=None, width=None, height=None):
+        """
+        Adds a tk widget into a guizero container.
+
+        :param tkinter.Widget tk_widget:
+            The Container (App, Box, etc) the tk widget will belong too.
+
+        :param List grid:
+            Grid co-ordinates for the widget, required if the master layout
+            is 'grid', defaults to `None`.
+
+        :param string align:
+            How to align the widget within the grid, defaults to None.
+
+        :param bool visible:
+            If the widget should be visible, defaults to `True`.
+
+        :param bool enabled:
+            If the widget should be enabled, defaults to `None`. If `None`
+            the value is inherited from the master.
+
+        :param int width:
+            The starting width of the widget. Defaults to `None` and will auto
+            size.
+
+        :param int height:
+            The starting height of the widget. Defaults to `None` and will auto
+            size.
+        """
+        # raise a warning if the tk widgets master is not this container
+        if self.tk is not tk_widget.master:
+            utils.error_format("The tk widget's master is not '{}'.\nIt may not display correctly.".format(self.description))
+        return Widget(self, tk_widget, "tk widget", grid, align, visible, enabled, width, height)
+
     def _add_child(self, child):
         """
         Associates a child widget with this widget.
@@ -306,7 +339,7 @@ class Container(Component):
 
         Should be called when the widgets need to be "re-packed/gridded".
         """
-        # All widgets are removed and then recreated to ensure the order they 
+        # All widgets are removed and then recreated to ensure the order they
         # were created is the order they are displayed.
 
         for child in self.children:
@@ -318,7 +351,7 @@ class Container(Component):
                     child.tk.pack_forget()
                 else:
                     child.tk.grid_forget()
-                
+
                 # display the widget
                 if child.visible:
                     if self.layout != "grid":
@@ -336,15 +369,9 @@ class Container(Component):
             pack_params["fill"] = X
         elif widget.height == "fill":
             pack_params["fill"] = Y
-            
+
         if widget.align is not None:
-            if widget.align in ["top", "bottom", "left", "right"]:
-                pack_params["side"] = widget.align
-            else:
-                utils.error_format("Invalid align value ('{}') for {}\nShould be: top, bottom, left or right".format(
-                    widget.align,
-                    widget.description
-                ))
+            pack_params["side"] = widget.align
 
         # this is to cater for scenario's where the frame will not expand to fill the container
         # if aligned - tk weirdness.
@@ -360,36 +387,21 @@ class Container(Component):
         widget.tk.pack(**pack_params)
 
     def _grid_widget(self, widget):
-        # If they failed to specify grid coords
-        if widget.grid is None:
-            utils.error_format("{} will not be displayed because it has a missing grid reference.".format(widget.description))
-        elif type(widget.grid) is not list:
-            utils.error_format("{} will not be displayed because the grid reference is not a list.".format(widget.description))
-        # Can have 2 values (just coords) or 4 values (coords and col/rowspan)
-        elif (len(widget.grid) != 2 and len(widget.grid) != 4):
-            utils.error_format("{} will not be displayed because the grid reference should be either grid=[x, y] or grid=[x, y, columnspan, rowspan].".format(widget.description))
-        else:
-            grid_params = {
-                "column": widget.grid[0],
-                "row": widget.grid[1]
-            }
 
-            # Just check we have more than 2 as we have already checked it's a multiple of two previously
-            if len(widget.grid) > 2:
-                grid_params["columnspan"] = widget.grid[2]
-                grid_params["rowspan"] = widget.grid[3]
+        grid_params = {
+            "column": widget.grid[0],
+            "row": widget.grid[1]
+        }
 
-            if widget.align is not None:
-                directions = {"top": "N", "bottom": "S", "left": "W", "right": "E"}
-                if widget.align in directions.keys():
-                    grid_params["sticky"] = directions[widget.align]
-                else:
-                    utils.error_format("Invalid align value ('{}') for {}\nShould be: top, bottom, left or right".format(
-                    widget.align,
-                    widget.description
-                ))
+        if len(widget.grid) == 4:
+            grid_params["columnspan"] = widget.grid[2]
+            grid_params["rowspan"] = widget.grid[3]
 
-            widget.tk.grid(**grid_params)
+        if widget.align is not None:
+            directions = {"top": "N", "bottom": "S", "left": "W", "right": "E"}
+            grid_params["sticky"] = directions[widget.align]
+
+        widget.tk.grid(**grid_params)
 
     @property
     def enabled(self):
@@ -439,6 +451,7 @@ class BaseWindow(Container):
         self.tk.title( str(title) )
         self.tk.geometry(str(width)+"x"+str(height))
         self._on_close = None
+        self._full_screen = False
 
         self.bg = bg
 
@@ -503,13 +516,32 @@ class BaseWindow(Container):
         else:
             self.hide()
 
+    # Whether the window is full screen or not
+    @property
+    def full_screen(self):
+        """
+        Sets or returns the visibility of the window
+        """
+        return self._full_screen
+
+    @full_screen.setter
+    def full_screen(self, make_full_screen):
+        if make_full_screen:
+            self.set_full_screen()
+        else:
+            self.exit_full_screen()
+
+    @property
+    def when_closed(self):
+        return self._on_close
+
+    @when_closed.setter
+    def when_closed(self, value):
+        self._on_close = value
+
     # METHODS
     # --------------------------------------
 
-    # Do `command` when the window is closed
-    def on_close(self, command):
-        self._on_close = command
-
     def hide(self):
         """Hide the window."""
         self.tk.withdraw()
@@ -529,6 +561,46 @@ class BaseWindow(Container):
     def update(self):
         self.tk.update()
 
+    def set_full_screen(self, keybind="<Escape>"):
+        """Make this window full screen and bind the Escape key (or given key) to exit full screen mode"""
+        self.tk.attributes("-fullscreen", True)
+        self._full_screen = True
+        self.events.set_event("<FullScreen.Escape>", keybind, self.exit_full_screen)
+
+    def exit_full_screen(self):
+        """Change from full screen to windowed mode and remove key binding"""
+        self.tk.attributes("-fullscreen", False)
+        self._full_screen = False
+        self.events.remove_event("<FullScreen.Escape>")
+    
+    def warn(self, title, text):
+        dialog.warn(title, text, master=self)
+
+    def info(self, title, text):
+        dialog.info(title, text, master=self)
+
+    def error(self, title, text):
+        dialog.error(title, text, master=self)
+
+    def yesno(self, title, text):
+        return dialog.yesno(title, text, master=self)
+
+    def question(self, title, question, initial_value=None):
+        return dialog.question(title, question, initial_value, master=self)
+
+    def select_file(self, title="Select file", folder=".", filetypes=[["All files", "*.*"]], save=False):
+        return dialog.select_file(title=title, folder=folder, filetypes=filetypes, save=save, master=self)
+
+    def select_folder(self, title="Select folder", folder="."):
+        return dialog.select_folder(title=title, folder=folder, master=self)
+
+    # DEPRECATED METHODS
+    # --------------------------------------------
+    def on_close(self, command):
+        # deprecated on 2019-06-08
+        self.when_closed = command
+        utils.deprecated("on_close() is deprecated. Please use the when_closed property instead.")
+
 
 class Widget(
     Component,
@@ -542,8 +614,8 @@ class Widget(
         The base class for a widget which is an interactable component e.g. `Picture`
         """
         super(Widget, self).__init__(master,tk, description, True)
-        self._grid = grid
-        self._align = align
+        self._update_grid(grid)
+        self._update_align(align)
         self._width = width
         self._height = height
         self.visible = visible
@@ -587,8 +659,8 @@ class ContainerWidget(
         The base class for a widget which is also a container e.g. `Box`, `ButtonGroup`
         """
         super(ContainerWidget, self).__init__(master,tk, description, layout, True)
-        self._grid = grid
-        self._align = align
+        self._update_grid(grid)
+        self._update_align(align)
         self._width = width
         self._height = height
         self.visible = visible
@@ -621,7 +693,7 @@ class ContainerWidget(
             propagate_function = self.tk.grid_propagate
 
         propagate_value = True
-        
+
         # if height or width > 0 need to stop propagation
         if isinstance(width, int):
             if width > 0:
@@ -635,7 +707,7 @@ class ContainerWidget(
         if isinstance(width, int) and isinstance(height, int):
             if (width == 0 and height > 0) or (height == 0 and width > 0):
                  utils.error_format("You must specify a width and a height for {}".format(self.description))
-        
+
         propagate_function(propagate_value)
 
 
