@@ -26,8 +26,6 @@ class ScheduleMixin():
 
     def _call_wrapper(self, time, function, *args):
         """Fired by tk.after, gets the callback and either executes the function and cancels or repeats"""
-        # execute the function
-        function(*args)
         if function in self._callback.keys():
             repeat = self._callback[function][1]
             if repeat:
@@ -37,6 +35,8 @@ class ScheduleMixin():
             else:
                 # remove it from the call back dictionary
                 self._callback.pop(function)
+        # execute the function
+        function(*args)
 
 
 class DestroyMixin():
@@ -238,10 +238,38 @@ class LayoutMixin():
     @property
     def grid(self):
         """
-        Returns `[x,y]` coordinates of this widget.
+        Sets or returns `[x,y]` coordinates of this widget.
         """
         return self._grid
 
+    @grid.setter
+    def grid(self, value):
+        self._update_grid(value)
+        self.master.display_widgets()
+
+    def _update_grid(self, grid):
+        """
+        Validates a Widgets grid property and stores it as a TriggeredList
+        which will call the masters display_widgets method when it is changed
+        """
+        self._grid = None
+        if self.master.layout == "grid":
+            # validate the grid
+            if grid is None:
+                utils.error_format("{} will not be displayed because it has a missing grid reference.".format(self.description))
+            elif not isinstance(grid, (list, tuple)):
+                utils.error_format("{} will not be displayed because the grid reference is not a list or tuple.".format(self.description))
+            # Can have 2 values (just coords) or 4 values (coords and col/rowspan)
+            elif (len(grid) != 2 and len(grid) != 4):
+                utils.error_format("{} will not be displayed because the grid reference should be either grid=[x, y] or grid=[x, y, columnspan, rowspan].".format(self.description))
+            else:
+                # convert the grid to a trackable list
+                self._grid = utils.TriggeredList(grid, on_change=self.master.display_widgets)
+        else:
+            if grid is not None:
+                utils.error_format("A grid is not required for {} as it is not using a 'grid' layout.".format(self.description))
+
+
     @property
     def align(self):
         """
@@ -249,6 +277,25 @@ class LayoutMixin():
         """
         return self._align
 
+    @align.setter
+    def align(self, value):
+        self._update_align(value)
+        self.master.display_widgets()
+
+    def _update_align(self, align):
+        """
+        Validates a widgets align property
+        """
+        self._align = None
+        if align is not None:
+            if align in ["top", "bottom", "left", "right"]:
+                self._align = align
+            else:
+                utils.error_format("Invalid align value ('{}') for {}\nShould be: top, bottom, left or right".format(
+                    align,
+                    self.description
+                ))
+
 
 class EventsMixin():
 
