@@ -2,6 +2,7 @@ from threading import Event
 from time import sleep
 from unittest.mock import MagicMock
 from guizero import Text, Picture
+from tkinter import Spinbox
 
 SET_FONT = "Times New Roman"
 TEST_FONTS = ["Times New Roman", "Liberation Serif"]
@@ -264,7 +265,7 @@ def cascading_enable_test(container):
     check_children(container, True)
 
 def cascading_properties_test(container):
-    t = Text(container)
+    t = Text(container, color=None, size=None, font=None)
     p = Picture(container)
 
     container.bg = "red"
@@ -293,7 +294,7 @@ def inheriting_properties_test(container):
     container.font = SET_FONT
     container.enabled = False
 
-    t = Text(container)
+    t = Text(container, color=None, size=None, font=None)
     assert t.bg == "red"
     assert t.text_color == "purple"
     assert t.text_size == 16
@@ -303,3 +304,102 @@ def inheriting_properties_test(container):
     p = Picture(container)
     assert p.bg == "red"
     assert not p.enabled
+
+def full_screen_test(window):
+    assert window.full_screen == False
+    window.full_screen = True
+    assert window.full_screen == True
+    window.full_screen = False
+    assert window.full_screen == False
+    window.set_full_screen()
+    assert window.full_screen == True
+    window.exit_full_screen()
+    assert window.full_screen == False
+
+def add_tk_widget_test(container):
+    s = Spinbox(from_=0, to=10)
+    sw = container.add_tk_widget(s)
+    assert s is not None
+    assert sw is not None
+    assert sw.grid is None
+    assert sw.align is None
+    assert sw.enabled
+    assert sw.visible
+    assert sw.width is None
+    assert sw.height is None
+    
+    s2 = Spinbox(from_=0, to=10)
+    sw = container.add_tk_widget(s2, align="left", visible=False, enabled=False, width="fill", height="fill")
+    assert s is not None
+    assert sw is not None
+    assert sw.align == "left"
+    assert not sw.enabled
+    assert not sw.visible
+    assert sw.width == "fill"
+    assert sw.height == "fill"
+
+def auto_layout_test(widget, align):
+    
+    assert widget.master.layout == "auto"
+    side = "top" if align is None else align
+    assert widget.tk.pack_info()["side"] == side
+
+    widget.align = "left"
+    assert widget.tk.pack_info()["side"] == "left"
+
+    widget.align = "right"
+    assert widget.tk.pack_info()["side"] == "right"
+
+    widget.align = "top"
+    assert widget.tk.pack_info()["side"] == "top"
+
+    widget.align = "bottom"
+    assert widget.tk.pack_info()["side"] == "bottom"
+
+def grid_layout_test(widget, x, y, col_span, row_span, align):
+
+    sticky = {"top": "n", "bottom": "s", "left": "w", "right": "e", None: ""}
+
+    # test initial values
+    assert widget.master.layout == "grid"
+    assert widget.tk.grid_info()["column"] == x
+    assert widget.tk.grid_info()["row"] == y
+    assert widget.tk.grid_info()["columnspan"] == col_span
+    assert widget.tk.grid_info()["rowspan"] == row_span
+    assert widget.tk.grid_info()["sticky"] == sticky[align]
+
+    # change grid values
+    widget.grid[0] = 3
+    widget.grid[1] = 4
+    assert widget.tk.grid_info()["column"] == 3
+    assert widget.tk.grid_info()["row"] == 4
+    assert widget.tk.grid_info()["columnspan"] == col_span
+    assert widget.tk.grid_info()["rowspan"] == row_span
+    assert widget.tk.grid_info()["sticky"] == sticky[align]
+
+    widget.grid = [5,6]
+    assert widget.tk.grid_info()["column"] == 5
+    assert widget.tk.grid_info()["row"] == 6
+    assert widget.tk.grid_info()["columnspan"] == 1
+    assert widget.tk.grid_info()["rowspan"] == 1
+    assert widget.tk.grid_info()["sticky"] == sticky[align]
+
+    widget.grid = (7,8)
+    assert widget.tk.grid_info()["column"] == 7
+    assert widget.tk.grid_info()["row"] == 8
+    assert widget.tk.grid_info()["columnspan"] == 1
+    assert widget.tk.grid_info()["rowspan"] == 1
+    assert widget.tk.grid_info()["sticky"] == sticky[align]
+
+    # change span
+    widget.grid = [9, 10, 11, 12]
+    assert widget.tk.grid_info()["column"] == 9
+    assert widget.tk.grid_info()["row"] == 10
+    assert widget.tk.grid_info()["columnspan"] == 11
+    assert widget.tk.grid_info()["rowspan"] == 12
+    assert widget.tk.grid_info()["sticky"] == sticky[align]
+
+    # change align
+    widget.align = "left"
+    assert widget.tk.grid_info()["sticky"] == sticky["left"]
+
