@@ -10,7 +10,10 @@ from common_test import (
     events_test,
     cascading_enable_test,
     cascading_properties_test,
-    inheriting_properties_test
+    inheriting_properties_test,
+    add_tk_widget_test,
+    grid_layout_test,
+    auto_layout_test
     )
 
 def test_default_values():
@@ -120,3 +123,28 @@ def test_inheriting_properties():
     b = Box(a)
     inheriting_properties_test(b)
     a.destroy()
+
+def test_add_tk_widget():
+    a = App()
+    add_tk_widget_test(a)
+    a.destroy()
+
+def test_auto_layout():
+    a = App()
+    w = Box(a)
+    auto_layout_test(w, None)
+    a.destroy()
+
+def test_grid_layout():
+    a = App(layout="grid")
+    
+    w = Box(a, grid=[1,2])
+    grid_layout_test(w, 1, 2, 1, 1, None)
+    
+    ws = Box(a, grid=[1,2,3,4])
+    grid_layout_test(ws, 1, 2, 3, 4, None)
+
+    wa = Box(a, grid=[1,2], align="top")
+    grid_layout_test(wa, 1, 2, 1, 1, "top")
+    
+    a.destroy()
