@@ -12,7 +12,9 @@ from common_test import (
     size_fill_test,
     events_test,
     cascaded_properties_test,
-    inherited_properties_test
+    inherited_properties_test,
+    grid_layout_test,
+    auto_layout_test
     )
 
 def test_default_values():
@@ -267,3 +269,23 @@ def test_inherited_properties():
     a = App()
     inherited_properties_test(a, lambda: ListBox(a, ["foo", "bar"]), True)
     a.destroy()
+
+def test_auto_layout():
+    a = App()
+    w = ListBox(a)
+    auto_layout_test(w, None)
+    a.destroy()
+
+def test_grid_layout():
+    a = App(layout="grid")
+    
+    w = ListBox(a, grid=[1,2])
+    grid_layout_test(w, 1, 2, 1, 1, None)
+    
+    ws = ListBox(a, grid=[1,2,3,4])
+    grid_layout_test(ws, 1, 2, 3, 4, None)
+
+    wa = ListBox(a, grid=[1,2], align="top")
+    grid_layout_test(wa, 1, 2, 1, 1, "top")
+    
+    a.destroy()
\ No newline at end of file
