@@ -10,7 +10,9 @@ from common_test import (
     color_test,
     events_test,
     cascaded_properties_test,
-    inherited_properties_test
+    inherited_properties_test,
+    grid_layout_test,
+    auto_layout_test
     )
 
 def test_default_values():
@@ -155,3 +157,23 @@ def test_inherited_properties():
     a = App()
     inherited_properties_test(a, lambda: Picture(a), False)
     a.destroy()
+
+def test_auto_layout():
+    a = App()
+    w = Picture(a)
+    auto_layout_test(w, None)
+    a.destroy()
+
+def test_grid_layout():
+    a = App(layout="grid")
+    
+    w = Picture(a, grid=[1,2])
+    grid_layout_test(w, 1, 2, 1, 1, None)
+    
+    ws = Picture(a, grid=[1,2,3,4])
+    grid_layout_test(ws, 1, 2, 3, 4, None)
+
+    wa = Picture(a, grid=[1,2], align="top")
+    grid_layout_test(wa, 1, 2, 1, 1, "top")
+    
+    a.destroy()
\ No newline at end of file
